Class: Aws::Health::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Health::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-health/client.rb,
sig/client.rbs
Overview
An API client for Health. To construct a client, you need to configure a :region and :credentials.
client = Aws::Health::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DescribeAffectedAccountsForOrganizationResponseSuccess, _DescribeAffectedEntitiesForOrganizationResponseSuccess, _DescribeAffectedEntitiesResponseSuccess, _DescribeEntityAggregatesForOrganizationResponseSuccess, _DescribeEntityAggregatesResponseSuccess, _DescribeEventAggregatesResponseSuccess, _DescribeEventDetailsForOrganizationResponseSuccess, _DescribeEventDetailsResponseSuccess, _DescribeEventTypesResponseSuccess, _DescribeEventsForOrganizationResponseSuccess, _DescribeEventsResponseSuccess, _DescribeHealthServiceStatusForOrganizationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#describe_affected_accounts_for_organization(params = {}) ⇒ Types::DescribeAffectedAccountsForOrganizationResponse
Returns a list of accounts in the organization from Organizations that are affected by the provided event.
-
#describe_affected_entities(params = {}) ⇒ Types::DescribeAffectedEntitiesResponse
Returns a list of entities that have been affected by the specified events, based on the specified filter criteria.
-
#describe_affected_entities_for_organization(params = {}) ⇒ Types::DescribeAffectedEntitiesForOrganizationResponse
Returns a list of entities that have been affected by one or more events for one or more accounts in your organization in Organizations, based on the filter criteria.
-
#describe_entity_aggregates(params = {}) ⇒ Types::DescribeEntityAggregatesResponse
Returns the number of entities that are affected by each of the specified events.
-
#describe_entity_aggregates_for_organization(params = {}) ⇒ Types::DescribeEntityAggregatesForOrganizationResponse
Returns a list of entity aggregates for your Organizations that are affected by each of the specified events.
-
#describe_event_aggregates(params = {}) ⇒ Types::DescribeEventAggregatesResponse
Returns the number of events of each event type (issue, scheduled change, and account notification).
-
#describe_event_details(params = {}) ⇒ Types::DescribeEventDetailsResponse
Returns detailed information about one or more specified events.
-
#describe_event_details_for_organization(params = {}) ⇒ Types::DescribeEventDetailsForOrganizationResponse
Returns detailed information about one or more specified events for one or more Amazon Web Services accounts in your organization.
-
#describe_event_types(params = {}) ⇒ Types::DescribeEventTypesResponse
Returns the event types that meet the specified filter criteria.
-
#describe_events(params = {}) ⇒ Types::DescribeEventsResponse
Returns information about events that meet the specified filter criteria.
-
#describe_events_for_organization(params = {}) ⇒ Types::DescribeEventsForOrganizationResponse
Returns information about events across your organization in Organizations.
-
#describe_health_service_status_for_organization(params = {}) ⇒ Types::DescribeHealthServiceStatusForOrganizationResponse
This operation provides status information on enabling or disabling Health to work with your organization.
-
#disable_health_service_access_for_organization(params = {}) ⇒ Struct
Disables Health from working with Organizations.
-
#enable_health_service_access_for_organization(params = {}) ⇒ Struct
Enables Health to work with Organizations.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-health/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1590 1591 1592 |
# File 'lib/aws-sdk-health/client.rb', line 1590 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1593 1594 1595 |
# File 'lib/aws-sdk-health/client.rb', line 1593 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'lib/aws-sdk-health/client.rb', line 1563 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Health') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-health' context[:gem_version] = '1.102.0' Seahorse::Client::Request.new(handlers, context) end |
#describe_affected_accounts_for_organization(params = {}) ⇒ Types::DescribeAffectedAccountsForOrganizationResponse
Returns a list of accounts in the organization from Organizations that are affected by the provided event. For more information about the different types of Health events, see Event.
Before you can call this operation, you must first enable Health to work with Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.
nextToken parameter
in the next request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
89 |
# File 'sig/client.rbs', line 89
def describe_affected_accounts_for_organization: (
|
#describe_affected_entities(params = {}) ⇒ Types::DescribeAffectedEntitiesResponse
Returns a list of entities that have been affected by the specified events, based on the specified filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the Amazon Web Services service. Events that have impact beyond that of the affected entities, or where the extent of impact is unknown, include at least one entity indicating this.
At least one event ARN is required.
nextToken
parameter in the next request to return more results.
- This operation supports resource-level permissions. You can use this operation to allow or deny access to specific Health events. For more information, see Resource- and action-based conditions in the Health User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
102 |
# File 'sig/client.rbs', line 102
def describe_affected_entities: (
|
#describe_affected_entities_for_organization(params = {}) ⇒ Types::DescribeAffectedEntitiesForOrganizationResponse
Returns a list of entities that have been affected by one or more events for one or more accounts in your organization in Organizations, based on the filter criteria. Entities can refer to individual customer resources, groups of customer resources, or any other construct, depending on the Amazon Web Services service.
At least one event Amazon Resource Name (ARN) and account ID are required.
Before you can call this operation, you must first enable Health to work with Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.
nextToken
parameter in the next request to return more results.
- This operation doesn't support resource-level permissions. You can't use this operation to allow or deny access to specific Health events. For more information, see Resource- and action-based conditions in the Health User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
131 |
# File 'sig/client.rbs', line 131
def describe_affected_entities_for_organization: (
|
#describe_entity_aggregates(params = {}) ⇒ Types::DescribeEntityAggregatesResponse
Returns the number of entities that are affected by each of the specified events.
156 |
# File 'sig/client.rbs', line 156
def describe_entity_aggregates: (
|
#describe_entity_aggregates_for_organization(params = {}) ⇒ Types::DescribeEntityAggregatesForOrganizationResponse
Returns a list of entity aggregates for your Organizations that are affected by each of the specified events.
166 |
# File 'sig/client.rbs', line 166
def describe_entity_aggregates_for_organization: (
|
#describe_event_aggregates(params = {}) ⇒ Types::DescribeEventAggregatesResponse
Returns the number of events of each event type (issue, scheduled change, and account notification). If no filter is specified, the counts of all events in each category are returned.
nextToken parameter
in the next request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
178 |
# File 'sig/client.rbs', line 178
def describe_event_aggregates: (
|
#describe_event_details(params = {}) ⇒ Types::DescribeEventDetailsResponse
Returns detailed information about one or more specified events. Information includes standard event data (Amazon Web Services Region, service, and so on, as returned by DescribeEvents), a detailed event description, and possible additional metadata that depends upon the nature of the event. Affected entities are not included. To retrieve the entities, use the DescribeAffectedEntities operation.
If a specified event can't be retrieved, an error message is returned for that event.
192 |
# File 'sig/client.rbs', line 192
def describe_event_details: (
|
#describe_event_details_for_organization(params = {}) ⇒ Types::DescribeEventDetailsForOrganizationResponse
Returns detailed information about one or more specified events for one or more Amazon Web Services accounts in your organization. This information includes standard event data (such as the Amazon Web Services Region and service), an event description, and (depending on the event) possible metadata. This operation doesn't return affected entities, such as the resources related to the event. To return affected entities, use the DescribeAffectedEntitiesForOrganization operation.
When you call the DescribeEventDetailsForOrganization operation,
specify the organizationEventDetailFilters object in the request.
Depending on the Health event type, note the following differences:
-
To return event details for a public event, you must specify a null value for the
awsAccountIdparameter. If you specify an account ID for a public event, Health returns an error message because public events aren't specific to an account. -
To return event details for an event that is specific to an account in your organization, you must specify the
awsAccountIdparameter in the request. If you don't specify an account ID, Health returns an error message because the event is specific to an account in your organization.
For more information, see Event.
204 |
# File 'sig/client.rbs', line 204
def describe_event_details_for_organization: (
|
#describe_event_types(params = {}) ⇒ Types::DescribeEventTypesResponse
Returns the event types that meet the specified filter criteria. You can use this API operation to find information about the Health event, such as the category, Amazon Web Services service, and event code. The metadata for each event appears in the EventType object.
If you don't specify a filter criteria, the API operation returns all event types, in no particular order.
nextToken parameter
in the next request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
221 |
# File 'sig/client.rbs', line 221
def describe_event_types: (
|
#describe_events(params = {}) ⇒ Types::DescribeEventsResponse
Returns information about events that meet the specified filter criteria. Events are returned in a summary form and do not include the detailed description, any additional metadata that depends on the event type, or any affected resources. To retrieve that information, use the DescribeEventDetails and DescribeAffectedEntities operations.
If no filter criteria are specified, all events are returned. Results
are sorted by lastModifiedTime, starting with the most recent event.
DescribeEvents operation and specify an entity
for the entityValues parameter, Health might return public events
that aren't specific to that resource. For example, if you call
DescribeEvents and specify an ID for an Amazon Elastic Compute
Cloud (Amazon EC2) instance, Health might return events that aren't
specific to that resource or service. To get events that are
specific to a service, use the services parameter in the filter
object. For more information, see Event.
- This API operation uses pagination. Specify the
nextTokenparameter in the next request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
241 |
# File 'sig/client.rbs', line 241
def describe_events: (
|
#describe_events_for_organization(params = {}) ⇒ Types::DescribeEventsForOrganizationResponse
Returns information about events across your organization in
Organizations. You can use thefilters parameter to specify the
events that you want to return. Events are returned in a summary form
and don't include the affected accounts, detailed description, any
additional metadata that depends on the event type, or any affected
resources. To retrieve that information, use the following operations:
If you don't specify a filter, the DescribeEventsForOrganizations
returns all events across your organization. Results are sorted by
lastModifiedTime, starting with the most recent event.
For more information about the different types of Health events, see Event.
Before you can call this operation, you must first enable Health to work with Organizations. To do this, call the EnableHealthServiceAccessForOrganization operation from your organization's management account.
nextToken parameter
in the next request to return more results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
255 |
# File 'sig/client.rbs', line 255
def describe_events_for_organization: (
|
#describe_health_service_status_for_organization(params = {}) ⇒ Types::DescribeHealthServiceStatusForOrganizationResponse
This operation provides status information on enabling or disabling Health to work with your organization. To call this operation, you must use the organization's management account.
291 292 |
# File 'sig/client.rbs', line 291
def describe_health_service_status_for_organization: () -> _DescribeHealthServiceStatusForOrganizationResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _DescribeHealthServiceStatusForOrganizationResponseSuccess
|
#disable_health_service_access_for_organization(params = {}) ⇒ Struct
Disables Health from working with Organizations. To call this operation, you must sign in to the organization's management account. For more information, see Aggregating Health events in the Health User Guide.
This operation doesn't remove the service-linked role from the management account in your organization. You must use the IAM console, API, or Command Line Interface (CLI) to remove the service-linked role. For more information, see Deleting a Service-Linked Role in the IAM User Guide.
295 296 |
# File 'sig/client.rbs', line 295
def disable_health_service_access_for_organization: () -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
|
#enable_health_service_access_for_organization(params = {}) ⇒ Struct
Enables Health to work with Organizations. You can use the organizational view feature to aggregate events from all Amazon Web Services accounts in your organization in a centralized location.
This operation also creates a service-linked role for the management account in the organization.
-
You must have a Business, Enterprise On-Ramp, or Enterprise Support plan from Amazon Web Services Support to use the Health API. If you call the Health API from an Amazon Web Services account that doesn't have a Business, Enterprise On-Ramp, or Enterprise Support plan, you receive a
SubscriptionRequiredExceptionerror. -
You must have permission to call this operation from the organization's management account. For example IAM policies, see Health identity-based policy examples.
If you don't have the required support plan, you can instead use the Health console to enable the organizational view feature. For more information, see Aggregating Health events in the Health User Guide.
299 300 |
# File 'sig/client.rbs', line 299
def enable_health_service_access_for_organization: () -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> ::Seahorse::Client::_ResponseSuccess[::Aws::EmptyStructure]
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1583 1584 1585 |
# File 'lib/aws-sdk-health/client.rb', line 1583 def waiter_names [] end |