Class: Aws::Health::Types::DescribeAffectedAccountsForOrganizationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Health::Types::DescribeAffectedAccountsForOrganizationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-health/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affected_accounts ⇒ Array<String>
A JSON set of elements of the affected accounts.
-
#event_scope_code ⇒ String
This parameter specifies if the Health event is a public Amazon Web Services service event or an account-specific event.
-
#next_token ⇒ String
If the results of a search are large, only a portion of the results are returned, and a
nextTokenpagination token is returned in the response.
Instance Attribute Details
#affected_accounts ⇒ Array<String>
A JSON set of elements of the affected accounts.
227 228 229 230 231 232 233 |
# File 'lib/aws-sdk-health/types.rb', line 227 class DescribeAffectedAccountsForOrganizationResponse < Struct.new( :affected_accounts, :event_scope_code, :next_token) SENSITIVE = [] include Aws::Structure end |
#event_scope_code ⇒ String
This parameter specifies if the Health event is a public Amazon Web Services service event or an account-specific event.
-
If the
eventScopeCodevalue isPUBLIC, then theaffectedAccountsvalue is always empty. -
If the
eventScopeCodevalue isACCOUNT_SPECIFIC, then theaffectedAccountsvalue lists the affected Amazon Web Services accounts in your organization. For example, if an event affects a service such as Amazon Elastic Compute Cloud and you have Amazon Web Services accounts that use that service, those account IDs appear in the response. -
If the
eventScopeCodevalue isNONE, then theeventArnthat you specified in the request is invalid or doesn't exist.
227 228 229 230 231 232 233 |
# File 'lib/aws-sdk-health/types.rb', line 227 class DescribeAffectedAccountsForOrganizationResponse < Struct.new( :affected_accounts, :event_scope_code, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the results of a search are large, only a portion of the results
are returned, and a nextToken pagination token is returned in the
response. To retrieve the next batch of results, reissue the search
request and include the returned token. When all results have been
returned, the response does not contain a pagination token value.
227 228 229 230 231 232 233 |
# File 'lib/aws-sdk-health/types.rb', line 227 class DescribeAffectedAccountsForOrganizationResponse < Struct.new( :affected_accounts, :event_scope_code, :next_token) SENSITIVE = [] include Aws::Structure end |