Class: Aws::Health::Types::DescribeAffectedEntitiesForOrganizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Health::Types::DescribeAffectedEntitiesForOrganizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-health/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#locale ⇒ String
The locale (language) to return information in.
-
#max_results ⇒ Integer
The maximum number of items to return in one batch, between 1 and 100, inclusive.
-
#next_token ⇒ String
If the results of a search are large, only a portion of the results are returned, and a
nextTokenpagination token is returned in the response. -
#organization_entity_account_filters ⇒ Array<Types::EntityAccountFilter>
A JSON set of elements including the
awsAccountId,eventArnand a set ofstatusCodes. -
#organization_entity_filters ⇒ Array<Types::EventAccountFilter>
A JSON set of elements including the
awsAccountIdand theeventArn.
Instance Attribute Details
#locale ⇒ String
The locale (language) to return information in. English (en) is the default and the only supported value at this time.
265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-health/types.rb', line 265 class DescribeAffectedEntitiesForOrganizationRequest < Struct.new( :organization_entity_filters, :locale, :next_token, :max_results, :organization_entity_account_filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in one batch, between 1 and 100, inclusive.
265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-health/types.rb', line 265 class DescribeAffectedEntitiesForOrganizationRequest < Struct.new( :organization_entity_filters, :locale, :next_token, :max_results, :organization_entity_account_filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the results of a search are large, only a portion of the results
are returned, and a nextToken pagination token is returned in the
response. To retrieve the next batch of results, reissue the search
request and include the returned token. When all results have been
returned, the response does not contain a pagination token value.
265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-health/types.rb', line 265 class DescribeAffectedEntitiesForOrganizationRequest < Struct.new( :organization_entity_filters, :locale, :next_token, :max_results, :organization_entity_account_filters) SENSITIVE = [] include Aws::Structure end |
#organization_entity_account_filters ⇒ Array<Types::EntityAccountFilter>
A JSON set of elements including the awsAccountId, eventArn and
a set of statusCodes.
265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-health/types.rb', line 265 class DescribeAffectedEntitiesForOrganizationRequest < Struct.new( :organization_entity_filters, :locale, :next_token, :max_results, :organization_entity_account_filters) SENSITIVE = [] include Aws::Structure end |
#organization_entity_filters ⇒ Array<Types::EventAccountFilter>
A JSON set of elements including the awsAccountId and the
eventArn.
265 266 267 268 269 270 271 272 273 |
# File 'lib/aws-sdk-health/types.rb', line 265 class DescribeAffectedEntitiesForOrganizationRequest < Struct.new( :organization_entity_filters, :locale, :next_token, :max_results, :organization_entity_account_filters) SENSITIVE = [] include Aws::Structure end |