Class: Aws::Health::Types::DescribeAffectedEntitiesForOrganizationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Health::Types::DescribeAffectedEntitiesForOrganizationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-health/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entities ⇒ Array<Types::AffectedEntity>
A JSON set of elements including the
awsAccountIdand itsentityArn,entityValueand itsentityArn,lastUpdatedTime, andstatusCode. -
#failed_set ⇒ Array<Types::OrganizationAffectedEntitiesErrorItem>
A JSON set of elements of the failed response, including the
awsAccountId,errorMessage,errorName, andeventArn. -
#next_token ⇒ String
If the results of a search are large, only a portion of the results are returned, and a
nextTokenpagination token is returned in the response.
Instance Attribute Details
#entities ⇒ Array<Types::AffectedEntity>
A JSON set of elements including the awsAccountId and its
entityArn, entityValue and its entityArn, lastUpdatedTime,
and statusCode.
296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-health/types.rb', line 296 class DescribeAffectedEntitiesForOrganizationResponse < Struct.new( :entities, :failed_set, :next_token) SENSITIVE = [] include Aws::Structure end |
#failed_set ⇒ Array<Types::OrganizationAffectedEntitiesErrorItem>
A JSON set of elements of the failed response, including the
awsAccountId, errorMessage, errorName, and eventArn.
296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-health/types.rb', line 296 class DescribeAffectedEntitiesForOrganizationResponse < Struct.new( :entities, :failed_set, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the results of a search are large, only a portion of the results
are returned, and a nextToken pagination token is returned in the
response. To retrieve the next batch of results, reissue the search
request and include the returned token. When all results have been
returned, the response does not contain a pagination token value.
296 297 298 299 300 301 302 |
# File 'lib/aws-sdk-health/types.rb', line 296 class DescribeAffectedEntitiesForOrganizationResponse < Struct.new( :entities, :failed_set, :next_token) SENSITIVE = [] include Aws::Structure end |