Class: Aws::Health::Types::Event
- Inherits:
-
Struct
- Object
- Struct
- Aws::Health::Types::Event
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-health/types.rb
Overview
Summary information about an Health event.
Health events can be public or account-specific:
-
*Public events* might be service events that are not specific to an Amazon Web Services account. For example, if there is an issue with an Amazon Web Services Region, Health provides information about the event, even if you don’t use services or resources in that Region.
-
Account-specific events are specific to either your Amazon Web Services account or an account in your organization. For example, if there’s an issue with Amazon Elastic Compute Cloud in a Region that you use, Health provides information about the event and the affected resources in the account.
You can determine if an event is public or account-specific by using the ‘eventScopeCode` parameter. For more information, see [eventScopeCode].
[1]: docs.aws.amazon.com/health/latest/APIReference/API_Event.html#AWSHealth-Type-Event-eventScopeCode
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actionability ⇒ String
The actionability classification of the event.
-
#arn ⇒ String
The unique identifier for the event.
-
#availability_zone ⇒ String
The Amazon Web Services Availability Zone of the event.
-
#end_time ⇒ Time
The date and time that the event ended.
-
#event_scope_code ⇒ String
This parameter specifies if the Health event is a public Amazon Web Services service event or an account-specific event.
-
#event_type_category ⇒ String
A list of event type category codes.
-
#event_type_code ⇒ String
The unique identifier for the event type.
-
#last_updated_time ⇒ Time
The most recent date and time that the event was updated.
-
#personas ⇒ Array<String>
A list of persona classifications that indicate the target audience for the event.
-
#region ⇒ String
The Amazon Web Services Region name of the event.
-
#service ⇒ String
The Amazon Web Services service that is affected by the event.
-
#start_time ⇒ Time
The date and time that the event began.
-
#status_code ⇒ String
The most recent status of the event.
Instance Attribute Details
#actionability ⇒ String
The actionability classification of the event. Possible values are ‘ACTION_REQUIRED`, `ACTION_MAY_BE_REQUIRED` and `INFORMATIONAL`. Events with `ACTION_REQUIRED` actionability require customer action to resolve or mitigate the event. Events with `ACTION_MAY_BE_REQUIRED` actionability indicates that the current status is unknown or conditional and inspection is needed to determine if action is required. Events with `INFORMATIONAL` actionability are provided for awareness and do not require immediate action.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The unique identifier for the event. The event ARN has the ‘arn:aws:health:event-region::event/SERVICE/EVENT_TYPE_CODE/EVENT_TYPE_PLUS_ID ` format.
For example, an event ARN might look like the following:
‘arn:aws:health:us-east-1::event/EC2/EC2_INSTANCE_RETIREMENT_SCHEDULED/EC2_INSTANCE_RETIREMENT_SCHEDULED_ABC123-DEF456`
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#availability_zone ⇒ String
The Amazon Web Services Availability Zone of the event. For example, us-east-1a.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time that the event ended.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#event_scope_code ⇒ String
This parameter specifies if the Health event is a public Amazon Web Services service event or an account-specific event.
-
If the ‘eventScopeCode` value is `PUBLIC`, then the `affectedAccounts` value is always empty.
-
If the ‘eventScopeCode` value is `ACCOUNT_SPECIFIC`, then the `affectedAccounts` value lists the affected Amazon Web Services accounts in your organization. For example, if an event affects a service such as Amazon Elastic Compute Cloud and you have Amazon Web Services accounts that use that service, those account IDs appear in the response.
-
If the ‘eventScopeCode` value is `NONE`, then the `eventArn` that you specified in the request is invalid or doesn’t exist.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#event_type_category ⇒ String
A list of event type category codes. Possible values are ‘issue`, `accountNotification`, or `scheduledChange`. Currently, the `investigation` value isn’t supported at this time.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#event_type_code ⇒ String
The unique identifier for the event type. The format is ‘AWS_SERVICE_DESCRIPTION `; for example, `AWS_EC2_SYSTEM_MAINTENANCE_EVENT`.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The most recent date and time that the event was updated.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#personas ⇒ Array<String>
A list of persona classifications that indicate the target audience for the event. Possible values are ‘OPERATIONS`, `SECURITY`, and `BILLING`. Events can be associated with multiple personas to indicate relevance to different teams or roles within an organization.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region name of the event.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
The Amazon Web Services service that is affected by the event. For example, ‘EC2`, `RDS`.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time that the event began.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ String
The most recent status of the event. Possible values are ‘open`, `closed`, and `upcoming`.
970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 |
# File 'lib/aws-sdk-health/types.rb', line 970 class Event < Struct.new( :arn, :service, :event_type_code, :event_type_category, :region, :availability_zone, :start_time, :end_time, :last_updated_time, :status_code, :event_scope_code, :actionability, :personas) SENSITIVE = [] include Aws::Structure end |