Class: Aws::Health::Types::DescribeAffectedEntitiesForOrganizationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-health/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#localeString

The locale (language) to return information in. English (en) is the default and the only supported value at this time.

Returns:

  • (String)


265
266
267
268
269
270
271
272
273
# File 'lib/aws-sdk-health/types.rb', line 265

class DescribeAffectedEntitiesForOrganizationRequest < Struct.new(
  :organization_entity_filters,
  :locale,
  :next_token,
  :max_results,
  :organization_entity_account_filters)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to return in one batch, between 10 and 100, inclusive.

Returns:

  • (Integer)


265
266
267
268
269
270
271
272
273
# File 'lib/aws-sdk-health/types.rb', line 265

class DescribeAffectedEntitiesForOrganizationRequest < Struct.new(
  :organization_entity_filters,
  :locale,
  :next_token,
  :max_results,
  :organization_entity_account_filters)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the results of a search are large, only a portion of the results are returned, and a ‘nextToken` pagination token is returned in the response. To retrieve the next batch of results, reissue the search request and include the returned token. When all results have been returned, the response does not contain a pagination token value.

Returns:

  • (String)


265
266
267
268
269
270
271
272
273
# File 'lib/aws-sdk-health/types.rb', line 265

class DescribeAffectedEntitiesForOrganizationRequest < Struct.new(
  :organization_entity_filters,
  :locale,
  :next_token,
  :max_results,
  :organization_entity_account_filters)
  SENSITIVE = []
  include Aws::Structure
end

#organization_entity_account_filtersArray<Types::EntityAccountFilter>

A JSON set of elements including the ‘awsAccountId`, `eventArn` and a set of `statusCodes`.

Returns:



265
266
267
268
269
270
271
272
273
# File 'lib/aws-sdk-health/types.rb', line 265

class DescribeAffectedEntitiesForOrganizationRequest < Struct.new(
  :organization_entity_filters,
  :locale,
  :next_token,
  :max_results,
  :organization_entity_account_filters)
  SENSITIVE = []
  include Aws::Structure
end

#organization_entity_filtersArray<Types::EventAccountFilter>

A JSON set of elements including the ‘awsAccountId` and the `eventArn`.

Returns:



265
266
267
268
269
270
271
272
273
# File 'lib/aws-sdk-health/types.rb', line 265

class DescribeAffectedEntitiesForOrganizationRequest < Struct.new(
  :organization_entity_filters,
  :locale,
  :next_token,
  :max_results,
  :organization_entity_account_filters)
  SENSITIVE = []
  include Aws::Structure
end